@@ -39,6 +39,18 @@ MainWindow::MainWindow(QWidget *parent) :
                                          "Created",
                                          this, SLOT(callIncoming()));
 
+    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
+                                         "/com/nokia/csd/call/1",
+                                         "com.nokia.csd.Call.Instance",
+                                         "Terminated",
+                                         this, SLOT(callEnded()));
+
+    if (inizializeAtStartUp)
+    {
+        qDebug()<<"Inizialize at start up is enabled, starting radio.";
+        startRadio();
+    }
+
 }
 
 MainWindow::~MainWindow()
@@ -207,6 +219,8 @@ void MainWindow::readSettings()
     stationListFontSize=settings.value("stationListFontSize", 20).toInt();
     lastFreq=settings.value("lastFreq").toInt();
     currentSet=settings.value("currentSet", 1).toInt();
+    resumeAfterCall=settings.value("resumeAfterCall", false).toBool();
+    inizializeAtStartUp=settings.value("inizializeAtStartUp", false).toBool();
 
     QSettings setSettings("qradio", "set" + QString::number(currentSet));
     quickAccessButtonsTextList = setSettings.value("quickAccessButtonsTextList", QStringList()<<"87.6"<< "101.0"<< "99.5"<< "102.3").toStringList();
@@ -541,7 +555,7 @@ void MainWindow::on_actionManual_triggered()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                    tr("<h2>QRadio 0.4.2</h2>"
+                    tr("<h2>QRadio 0.4.3</h2>"
                        "<p>"
                        "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 }
@@ -625,10 +639,12 @@ void MainWindow::on_actionAuto_Scan_triggered()
 
 void MainWindow::callIncoming()
 {
-    qDebug()<<"call incoming";
+    qDebug()<<"Call incoming/created";
 
     if (radio==0) return;
 
+    qDebug()<<"Stopping radio.";
+
     metaDataTimer->stop();
     saveSettings();
     setWidgetsEnabled(false);
@@ -636,3 +652,45 @@ void MainWindow::callIncoming()
     radio=0;
     QProcess::execute("sh /opt/qradio/restoremicrophone.sh");
 }
+
+void MainWindow::callEnded()
+{
+    qDebug()<<"Call ended";
+
+    if (!resumeAfterCall)
+    {
+        qDebug()<<"Resuming after call is not enabled";
+        return;
+    }
+
+    qDebug()<<"Resuming after call enabled, restarting radio.";
+
+    QFile file("/sys/devices/platform/gpio-switch/headphone/state");
+    file.open(QIODevice::ReadOnly | QIODevice::Text);
+    QTextStream t( &file );
+    QString headphoneStatus;
+    headphoneStatus = t.readLine();
+    qDebug()<<"Headphone status: "<<headphoneStatus;
+    file.close();
+
+    if (headphoneStatus == "disconnected")
+    {
+        return;
+    }
+
+    radio = new QRadioTuner;
+    connect(radio,SIGNAL(frequencyChanged(int)),this,SLOT(freqChanged(int)));
+    connect(radio, SIGNAL(metaDataChanged()), SLOT(getMetaData()));
+    connect(radio, SIGNAL(metaDataAvailableChanged(bool)), SLOT(getMetaData()));
+    connect(radio, SIGNAL(signalStrengthChanged(int)), SLOT(signalChanged()));
+    if (radio->isBandSupported(QRadioTuner::FM))
+    {
+        radio->setBand(QRadioTuner::FM);
+        radio->setFrequency(lastFreq);
+        radio->setVolume(ui->volumeSlider->value());
+        radio->start();
+    }
+
+    metaDataTimer->start(10000);
+    setWidgetsEnabled(true);
+}
